<?php
// Exit if accessed directly
if (!defined('ABSPATH')) {
  die('Un-authorized access!');
}

/**
 * Detect plugin. For use in Admin area only.
 */
include_once(ABSPATH . 'wp-admin/includes/plugin.php');
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://www.365leadmanagement.com
 * @since      0.1.0
 *
 * @package    Lead_Crm
 * @subpackage Lead_Crm/admin/partials
 */
function render_admin_page()
{
?>
  <div id="leadcrm-page" @vue:mounted="onMounted()">
    <div class="max-w-984 mx-auto bg-white text-dark text-center py-16 p-8 mt-8 bg-blue">
      <div class="max-w-2xl mx-auto">
        <img class="mb-6 mx-auto border-0" :src="logoUrl" style="max-width: 1500px" />
        <h1 class="text-xxl font-bold text-dark mb-6 mt-8 truncate">Send Leads to 365 Lead Management CRM</h1>
        <p class="mb-12 text-base">
        Receive immediate email and mobile app notifications for new leads submitted through your WordPress contact forms. Easily manage leads and initiate calls, WhatsApp, SMS, and emails with just one touch using 365 Lead Management CRM.
        </p>

        <!-- Token Field -->
        <div class="text-left mb-6">
          <label class="block text-gray-700 text-sm font-semibold mb-2" for="leadcrm_token">
            365 Lead Management CRM Account Token
          </label>
          <input id="leadcrm_token" v-model="leadcrmToken" class="leadcrm-text-input" :class="getTokenClasses()" type="text" placeholder="WP-ABCD1234" @keydown="isFormDirty = true" />
          <div class="text-xs text-red-700 tracking-wider font-normal mt-2" v-if="leadcrmTokenError">
            {{ leadcrmTokenError }}
          </div>
          <!-- <p class="my-1 text-gray-500">
            Get your 365 Lead management Account Token under your <strong>365 Lead management Integrations tab >
              <a :href="webappIntegrationPageLink" target="_blank" class="leadcrm-external-link">
                WordPress Websites
              </a>
            </strong>
          </p> -->
        </div>

        <!-- Website Name Field -->
        <div class="text-left mb-6" v-if="isIntegrated">
          <label class="block text-gray-700 text-sm font-semibold mb-2" for="cf_reference">
            Website Name (Optional)
          </label>
          <input id="cf_reference" v-model="cfReference" class="leadcrm-text-input border-gray-500" type="text" placeholder="e.g. ACME Corporation Website" @keydown="isFormDirty = true" />
          <p class="my-1 text-gray-500">
            The Website Name field will be displayed on your new lead alerts and client details
            to let you know where the lead came from
          </p>
        </div>

        <div class="text-left mb-4">
          <label class="block text-gray-700 text-sm font-semibold mb-2">
            Contact Forms
          </label>
          <p v-if="isIntegrated" class="my-1">
          Choose the WordPress contact form(s) you want to link. Once linked, you can test submitting a lead on your contact form to verify its successful integration with your 365 Lead management account.
          </p>
          <p v-else class="my-1">
            365 Lead management works with most of the popular WordPress contact form plugins.
            Simply enter your 365 Lead management Account Token above and hit SAVE to connect your installed contact forms.
          </p>
        </div>

        <!-- 
          Integration Tag, 
          only shows for the first time when user not fill their token yet 
        -->
        <div class="text-left" v-if="!isIntegrated">
          <span v-for="(integration, index) in installedIntegrations" :key="index" class="bg-badge inline-block px-3 py-1 rounded-full font-bold mr-2 mb-2 uppercase">
            <img class="inline float-left mr-2" style="max-height: 16px" :src="integration.iconUrl" />
            {{ integration.name }}
          </span>
        </div>

        <!-- List of integration toggle boxes -->
        <div class="text-left" v-else>
          <div v-for="(integration, index) in availableIntegrations" class="border mb-4 p-4" :class="getFieldClasses(integration)">
            <label class="leadcrm-integration-header flex" :for="integration.key">
              <img class="inline float-left mr-2" style="max-width: 16px" :src="integration.iconUrl" />
              <span class="flex-1">
                {{ integration.name }}
              </span>
              <label class="connected mr-4" v-if="integration.status === Status.Connected && integration.enabled">
                Connected!
              </label>
              <label class="text-sky-600 font-bold mr-4" v-else-if="integration.status === Status.Activated && integration.enabled">
                Save to Confirm
              </label>
              <div class="relative inline-block w-10 mr-2 align-middle select-none transition duration-200 ease-in self-end">
                <input v-model="integration.enabled" @change="handleOnToggleChange(index)" type="checkbox" name="toggle" :id="integration.key" class="toggle-checkbox absolute block w-5 h-5 rounded-full bg-white appearance-none cursor-pointer" />
                <label :for="integration.key" class="toggle-label block overflow-hidden w-8 h-4 rounded-full bg-gray-300 cursor-pointer"></label>
              </div>
            </label>
            <div class="text-xs text-red-700 tracking-wider font-normal mt-2" v-if="integration.errorMessage">
              {{ integration.errorMessage }}
            </div>
          </div>
        </div>

        <button class="btn w-3/4 btn-secondary disabled:bg-gray-disabled disabled:text-gray-500" :class="isIntegrated ? 'mt-3' : 'mt-8'" :disabled="!isFormDirty || isSubmitting" @click="handleSubmit">
          {{isSubmitting ? 'Saving...' : 'Save'}}
        </button>
      </div>
    </div>

    <!-- Help Footer Text -->
    <p class="text-center text-gray-400 text-sm mt-4">
      Check out our help guide for more details on
      <a href="https://www.365leadmanagement.com/knowledge-base/wordpress-integration/" class="leadcrm-external-link" target="_blank">
        connecting WordPress to 365 lead management CRM
      </a>
    </p>
    <p class="text-center text-gray-400 text-sm mt-4">
      Need help?
      <a href="mailto:support@365leadmanagement.com" class="leadcrm-external-link">
        Contact 365 Lead Manegement Support
      </a>
    </p>

    <!-- Toast -->
    <div class="flex justify-center fixed bottom-7 z-100" style="width: -webkit-fill-available">
      <div v-show="toast.visible" class="shadow-lg px-6 py-2 rounded-full flex items-center justify-center" :class="getToastStyles()">
        <div class="toast-icon mr-4"></div>
        <div class="flex flex-col text-sm tracking-wide mr-6">
          <div class="font-medium">{{ toast.heading }}</div>
          <div>{{ toast.message }}</div>
        </div>
        <button class="ml-auto px-3 py-2 rounded-full focus:outline-none" @click="toast.visible = false">
          <div class="toast-close-icon"></div>
        </button>
      </div>
    </div>
  </div>

  <script>
    <?php
    $leadcrm_config = Leadcrm_Options::get_values();
    $data_from_wp = array(
      "wordpressAjaxUrl" => esc_url(admin_url('admin-ajax.php')),
      "leadcrmWebhookSubscriptionUrl" =>  Leadcrm_Constants::get_webhook_subscription_url(),
      "webappIntegrationPageLink" => Leadcrm_Constants::WEBAPP_INTEGRATION_PAGE_LINK,
      "formActionName" => Leadcrm_Constants::WP_SAVE_HOOK_NAME,
      "logoUrl" => Leadcrm_Constants::get_logo_url(),
      "availableIntegrations" => Leadcrm_Options::get_available_integrations(),
      "leadcrmToken" => isset($leadcrm_config['leadcrm_token']) ? $leadcrm_config['leadcrm_token'] : '',
      "cfReference" => isset($leadcrm_config['cf_reference']) ? $leadcrm_config['cf_reference'] : '',
      "Status" => Leadcrm_Integration_Status::to_array()
    );
    ?>

    // Load variables from PHP into javascript realm;
    const dataFromWP = <?php echo json_encode($data_from_wp, JSON_HEX_TAG); ?>;

    PetiteVue.createApp({
      // === All embedded data from Wordpress PHP ===
      ...dataFromWP,

      // === Data or Computed ===
      isSubmitting: false,
      isIntegrated: !!dataFromWP.leadcrmToken,
      leadcrmTokenError: null,
      isFormDirty: false,
      toast: {
        visible: false,
        type: '',
        heading: '',
        message: ''
      },
      installedIntegrations: dataFromWP.availableIntegrations,

      // === Lifecycle ===
      onMounted() {
        const url = new URL(window.location.href)
        if (!url.searchParams.has('success')) return
        this.showToast({
          type: 'success',
          heading: 'Saved',
          message: 'Success! Your updates have been saved'
        })
      },

      // === Methods === 
      getFieldClasses(integration) {
        if (integration.enabled) {
          if (integration.status === dataFromWP.Status.Connected) {
            return 'border-green-400 bg-green-100'
          }
          if (integration.status === dataFromWP.Status.Activated) {
            return 'border-sky-400 bg-sky-100'
          }
        }
        return 'border-gray-200 bg-gray-50'
      },

      getInputClasses(integration) {
        if (integration.status === dataFromWP.Status.Connected) return 'border-green-400 connected'
        return 'border-gray-500'
      },

      getTokenClasses() {
        if (this.leadcrmTokenError) return 'border-red-400 text-red-700 error'
        return 'border-gray-500'
      },

      getToastStyles() {
        const styles = {
          error: 'toast-error bg-fire-light text-fire',
          success: 'toast-success bg-secondary-light text-secondary'
        }
        return styles[this.toast.type]
      },

      clearAllErrors() {
        this.leadcrmTokenError = null
        this.availableIntegrations.forEach((_, index) => {
          this.availableIntegrations[index].errorMessage = null
        })
      },

      getPayload() {
        return this.availableIntegrations
          .filter(integration => integration.status !== this.Status.NotExist)
          .filter(integration => integration.enabled)
          .reduce((prev, integration) => ({
            ...prev,
            [integration.key]: integration.enabled
          }), {
            leadcrm_token: this.leadcrmToken
          })

      },

      tryRegisterToken() {
        const payload = this.getPayload()
        return fetch(this.leadcrmWebhookSubscriptionUrl, {
            method: 'POST',
            headers: {
              'Content-Type': 'application/json'
            },
            body: JSON.stringify(payload)
          })
          .then(response => response.json())
          .then((result) => {
            // Plugin Accepeted Response     
            if (result.status && result.status !== "False") {
              return result
            }
            this.leadcrmTokenError = result.description
            const error = new Error('Oops! The 365 Lead Management Account Token is not valid. Please check and try again.')
            error.heading = 'Invalid 365 Lead Management Token'
            throw error
          })
      },

      saveFormIntoWP() {
        const payload = this.getPayload()
        return fetch(this.wordpressAjaxUrl, {
          method: 'POST',
          body: new URLSearchParams({
            ...payload,
            action: this.formActionName,
            cf_reference: this.cfReference
          })
        })
      },

      handleOnToggleChange(index) {
        const status = this.availableIntegrations[index].status
        const errorMessageMap = {
          [this.Status.NotExist]: 'Oops! This plugin or theme isn\'t currently activated on your WordPress site.',
          [this.Status.Installed]: 'Oops! This plugin or theme isn\'t currently activated on your WordPress site.',
        }
        const errorMessage = errorMessageMap[status]
        if (!errorMessage) {
          this.isFormDirty = true
          return
        }
        this.availableIntegrations[index].errorMessage = errorMessage

        // Revert the toggle value after short delay
        const delay = 200 // in ms
        setTimeout(() => {
          this.availableIntegrations[index].enabled = false
        }, delay)
      },

      handleSubmit() {
        this.clearAllErrors();
        this.isSubmitting = true
        this.tryRegisterToken()
          .then(this.saveFormIntoWP)
          .then(() => {
            window.location.search += "&success=true"
          })
          .catch((error) => {
            this.isSubmitting = false
            this.showToast({
              type: 'error',
              heading: error.heading,
              message: error.message.includes('not valid') ? error.message : null
            })
          })
      },

      showToast(params) {
        this.toast.visible = true
        this.toast.type = params.type
        this.toast.heading = params.heading || 'Errors Detected'
        this.toast.message = params.message || 'There were one or more errors detected. Please check and try again.'

        // Auto close after 3s
        const delay = 3000
        setTimeout(() => {
          this.toast.visible = false
        }, delay)
      }
    }).mount("#leadcrm-page")
  </script>
<?php
}
//<!-- This file should primarily consist of HTML with a little bit of PHP. -->
