<?php
// Exit if accessed directly
if (!defined('ABSPATH')) {
    die('Un-authorized access!');
}

class Leadcrm_Elementor_Form
{
    private function extract_value_by_type($field)
    {
        // Masking password into static 8 chars asterisk
        if ($field['type'] === 'password') return '********';
        return $field['value'];
    }

    /**
     * Reformat elementor form fields into dict key value pair
     * So it is easier to be consumed by our webhook API
     */
    private function format_fields_payload($fields)
    {
        $body = array();
        foreach ($fields as $field) {
            $key = _lead_crm_get_form_key($field, 'title', array('type', 'id'));
            $body[$key] = $this->extract_value_by_type($field);
        }
        return $body;
    }

    /** 
     * This is a elementor form callback after the lead is submitted.
     * Calls a non blocking http API request to 365 CRM with lead data.
     */
    public function submit_elementor_form_to_leadcrm($record, $handler)
    {
        $form_name = $record->get_form_settings('form_name');
        $raw_fields = $record->get('fields');
        $token = Leadcrm_Options::get_single_value('leadcrm_token');
        $cf_reference = Leadcrm_Options::get_single_value('cf_reference');
        $leadcrm_api = new Leadcrm_API('elementor_form', $form_name);
        $endpoint = $leadcrm_api->build_api_endpoint();
        $payload = $this->format_fields_payload($raw_fields);
        $payload['form_name'] = $form_name;
        $payload['leadcrm_token'] = $token;
        $payload['cf_reference'] = $cf_reference;

        $leadcrm_api->submit_lead_to_leadcrm($endpoint, $payload, Content_Type::FORM_URLENCODED);
    }
}
